==================================
 Invenio-Pages v0.1.1 is released
==================================

Invenio-Pages v0.1.1 was released on August 25, 2015.

About
-----

Invenio module that adds support for static pages.

*This is an experimental development preview release.*

Bug fixes
---------

- Adds missing `invenio_upgrader` dependency and amends past upgrade
  recipes following its separation into standalone package.

- Overrides default wtforms field for content column in order to
  display it properly. (closes inveniosoftware/invenio#3311)

Installation
------------

   $ pip install invenio-pages==0.1.1

Documentation
-------------

   http://invenio-pages.readthedocs.org/en/v0.1.1

Happy hacking and thanks for flying Invenio-Pages.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-pages
|   URL: http://invenio-software.org
